stac.nonparametric_tests.friedman_test — STAC Release Candidate documentation

### Navigation

- index
- STAC Release Candidate documentation »

# stac.nonparametric_tests.friedman_test

`stac.nonparametric_tests.` `friedman_test`(*args)

  Performs a Friedman ranking test. Tests the hypothesis that in a set of k dependent samples groups (where k >= 2) at least two of the groups represent populations with different median values.

  Parameters: | sample1, sample2, ... : array_like The sample measurements for each group.
  Returns: | F-value : float The computed F-value of the test. p-value : float The associated p-value from the F-distribution. rankings : array_like The ranking for each group. pivots : array_like The pivotal quantities for each group.

  References

  M. Friedman, The use of ranks to avoid the assumption of normality implicit in the analysis of variance, Journal of the American Statistical Association 32 (1937) 674–701. D.J. Sheskin, Handbook of parametric and nonparametric statistical procedures. crc Press, 2003, Test 25: The Friedman Two-Way Analysis of Variance by Ranks

### Navigation

- index
- STAC Release Candidate documentation »